<!--
SPDX-FileCopyrightText: 2026 Knitli Inc.

SPDX-License-Identifier: MIT OR Apache-2.0
-->

# Changelog

## v1.0.1

- No notable changes, bumping to overcome a pypi metadata issue.

## v1.0.0

- No breaking changes. Bumping to 1.0 to reflect stable, feature-complete status.

## v0.1.0

- Initial transfer from [CodeWeaver](https://github.com/knitli/codeweaver)
- Added tests to reach full coverage
